//the gallery is fairly simple. the host I'm using only allows HTML, CSS, and Javascript, so proper utilization of this gallery requires all the files to be given standardized names beforehand. 
//On windows systems, this is as simple as highlighting a list of like images, selecting rename, and coming up with the term that makes them alike. In this instance, typing "Apricot" while selecting nine images of my cat names them "Apricot (1)" through "Apricot (9)"
//this is easy to modify for different system conventions.

//we define the function "activateGallery" that takes two parameters. This function is activated onclick from a button element on the gallery page. The two parameters are the gallery name (apricot, in this instance), and the number of photos in the gallery (9, currently)
function activateGallery(gallery, qty){
    //we define a variable, currentPhoto, and set it to be one. This is the current 'place' within the gallery
    let currentPhoto = 1;

    //we load the gallery, which exists on the gallery.html page in an inactive state. we do this by setting the class name to be 'active'
    elemID('galleryLoaded').className = 'active';
    //we set the innerhtml of the 'galleryDisplay' div (the div that houses the image) to be equal to an image in the Images folder. We set this to be the first image by default when loading the gallery.
    elemID('galleryDisplay').innerHTML = `<img src='Images/${gallery} (1).jpg'/>`;
    //this simply prints the place in the gallery. in this instance, on loading, it would be 1/9
    elemID('galleryCounter').innerHTML = `${currentPhoto} / ${qty}`;

    //we bind event listeners here. we bind a keydown listener to the entire document, and click listeners to the "left", "right", and "exit" elements of the gallery. 
    document.addEventListener("keydown",photoNav);
    elemID('left').addEventListener('click',photoNav)
    elemID('right').addEventListener('click',photoNav)
    elemID('exit').addEventListener('click',deactivateGallery)

    //the photoNav function takes one paramater, equal to whatever value is passed by the event listener that calls it
    function photoNav(e){
        //our first if checks to see if any of the event listeners correlate to progressing the gallery forward. if the right arrow is clicked, the right arrow key is pressed, or the d key is pressed, it increments the currentPhoto variable by one.
        //it only does this if the currentPhoto integer is less than the total number of images in the gallery
        if ((e.key == 'ArrowRight' | e.key == 'd' | e.target.id=='right') && (currentPhoto < qty)){
            currentPhoto+=1;

        //the next if statement does the same as the first, but in the opposite direction, decrementing the currentPhoto by one if it is greater than 1
        }else if((e.key == 'ArrowLeft' | e.key=='a' | e.target.id=='left') && (currentPhoto>1)){
            currentPhoto-=1;
        
        //the last if statement checks to see if the 'escape' key is pressed. if it is, it runs the deactivateGallery function, and returns null
        }else if(e.key=='Escape'){
            deactivateGallery();
            return null;
        }

        //the last part of this function is changing the image and the counter.
        //all we do is change the innerHTML of the galleryDisplay element to be an image equal to the currentPhoto integer in the gallery
        elemID('galleryDisplay').innerHTML = `<img src='Images/${gallery} (${currentPhoto}).jpg'/>`;
        elemID('galleryCounter').innerHTML = `${currentPhoto} / ${qty}`;
    }

    //the deactivateGallery function is simple. When the escape key is pressed or the exit element is clicked, it runs.
    function deactivateGallery(){
        //we set the container div "galleryLoaded" to have the class name "inactive", which is set to display:None in our style rules
        elemID('galleryLoaded').className = 'inactive';
        //we then remove the keydown and click event listeners we set up. This prevents any potential issues with functions firing off while the gallery is closed. 
        elemID('exit').removeEventListener('click',deactivateGallery)
        elemID('left').removeEventListener('click',photoNav)
        elemID('right').removeEventListener('click',photoNav)
        document.removeEventListener("keydown",photoNav);
    }
}